@@ -59,16 +59,21 @@
 #define QT_FEATURE_test_gui 1
 
 
-#define QT_VERSION_STR "6.9.2"
+#define QT_VERSION_STR "6.9.3"
 
 #define QT_VERSION_MAJOR 6
 
 #define QT_VERSION_MINOR 9
 
-#define QT_VERSION_PATCH 2
+#define QT_VERSION_PATCH 3
 
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
+#define QT_COMPILER_SUPPORTS_NEON 1
+#define QT_COMPILER_SUPPORTS_CRC32 1
+#define QT_COMPILER_SUPPORTS_CRYPTO 1
+#define QT_COMPILER_SUPPORTS_AES 1
+#define QT_COMPILER_SUPPORTS_SVE 1
 #define QT_LINKED_OPENSSL
 #define QT_GUI_TEST 1
